-- table of languages --
CREATE TABLE TRANS_LANG
(
  LANG_CODE   VARCHAR2(2 BYTE)                      NULL,
  LANG_LABEL  VARCHAR2(100 BYTE)                    NULL
)
/

ALTER TABLE TRANS_LANG ADD (
  PRIMARY KEY (LANG_CODE))
/

INSERT INTO TRANS_LANG ( LANG_CODE, LANG_LABEL ) VALUES ('EN', 'English'); 
INSERT INTO TRANS_LANG ( LANG_CODE, LANG_LABEL ) VALUES ('FR', 'French'); 
COMMIT
/

-- table of items --
CREATE TABLE TRANS_ITEMS
(
  MODULE    VARCHAR2(30 BYTE)                       NULL,
  BLOCK     VARCHAR2(30 BYTE)                       NULL,
  ITEM      VARCHAR2(30 BYTE)                       NULL,
  LANG      VARCHAR2(2 BYTE)                        NULL,
  TYPE      VARCHAR2(30 BYTE)                       NULL,
  LABEL     VARCHAR2(128 BYTE)                      NULL,
  PROMPT    VARCHAR2(128 BYTE)                      NULL,
  SHORT_LB  VARCHAR2(20 BYTE)                       NULL,
  HINT      VARCHAR2(256 BYTE)                      NULL,
  TOOLTIP   VARCHAR2(256 BYTE)                      NULL
)
/


CREATE UNIQUE INDEX TRANS_ITEMS_PK ON TRANS_ITEMS
(MODULE, BLOCK, ITEM, TYPE, LANG)
/


ALTER TABLE TRANS_ITEMS ADD (
  CONSTRAINT TRANS_ITEMS_PK PRIMARY KEY (MODULE, BLOCK, ITEM, TYPE, LANG))
/


ALTER TABLE TRANS_ITEMS ADD (
  CONSTRAINT TRANS_ITEMS_FK FOREIGN KEY (LANG) 
    REFERENCES TRANS_LANG (LANG_CODE))
/

-- table of single objects --
CREATE TABLE TRANS_OBJECTS
(
  MODULE  VARCHAR2(30 BYTE)                         NULL,
  LANG    VARCHAR2(2 BYTE)                          NULL,
  TYPE    VARCHAR2(30 BYTE)                         NULL,
  NAME    VARCHAR2(30 BYTE)                         NULL,
  TITLE   VARCHAR2(256 BYTE)                        NULL
)
/


CREATE UNIQUE INDEX TRANS_OBJECTS_PK ON TRANS_OBJECTS
(MODULE, NAME, TYPE, LANG)
/


ALTER TABLE TRANS_OBJECTS ADD (
  CONSTRAINT TRANS_OBJECTS_PK PRIMARY KEY (MODULE, NAME, TYPE, LANG))
/


ALTER TABLE TRANS_OBJECTS ADD (
  CONSTRAINT TRANS_OBJECTS_FK FOREIGN KEY (LANG) 
    REFERENCES TRANS_LANG (LANG_CODE))
/

-- table of options --
CREATE TABLE TRANS_OPTIONS
(
  MODULE  VARCHAR2(30 BYTE)                         NULL,
  BLOCK   VARCHAR2(30 BYTE)                         NULL,
  ITEM    VARCHAR2(30 BYTE)                         NULL,
  LANG    VARCHAR2(2 BYTE)                          NULL,
  TYPE    VARCHAR2(30 BYTE)                         NULL,
  NAME    VARCHAR2(30 BYTE)                         NULL,
  LABEL   VARCHAR2(128 BYTE)                        NULL,
  PROMPT  VARCHAR2(128 BYTE)                        NULL
)
/


CREATE UNIQUE INDEX TRANS_OPTIONS_PK ON TRANS_OPTIONS
(MODULE, BLOCK, ITEM, TYPE, LANG, NAME)
/


ALTER TABLE TRANS_OPTIONS ADD (
  CONSTRAINT TRANS_OPTIONS_PK PRIMARY KEY (MODULE, BLOCK, ITEM, TYPE, LANG, NAME))
/


ALTER TABLE TRANS_OPTIONS ADD (
  CONSTRAINT TRANS_OPTIONS_FK FOREIGN KEY (LANG) 
    REFERENCES TRANS_LANG (LANG_CODE))
/
